@@ -15,7 +15,7 @@
 #
 #
 
-from outlook import OutlookExpressClient
+from unforward.emailclients.outlook import OutlookExpressClient
 
 
 class iPhoneClient(OutlookExpressClient):
