@@ -29,14 +29,13 @@ import codecs
 def main():
     """ The main starting point for the unforward script."""
     sys.stdin = codecs.getreader('utf-8')(sys.stdin)
+    email_text = sys.stdin.read()
+    
     extractor = unforward.Extractor()
     try:
         if '--html' in sys.argv:
-            sys.argv.remove('--html')
-            email_text = ''.join(line for line in fileinput.input( ) )
             result = extractor.extract_from_html(email_text)
-        else:    
-            email_text = ''.join(line for line in fileinput.input( ) )
+        else:
             result = extractor.extract(email_text)
         result['date'] = result['date'].strftime(r"%Y-%m-%dT%H:%M:%S %z")
         print(json.dumps(result))
